import { createContext, useContext, useState } from "react";

const preview = {
  username: "",
  setUsername: () => {},
  permissions: [],
  setPermissions: () => {},
  paymentPlanStatus: "",
  setPaymentPlanStatus: () => {},
  paymentPlanTrialEnd: "",
  setPaymentPlanTrialEnd: () => {},
  paymentPlanCanceledAt: "",
  setPaymentPlanCanceledAt: () => {},
};

const SideBarContext = createContext(preview);

export const useSideBarContext = () => useContext(SideBarContext);

export default function SideBarProvider({ children, options }) {
  const [username, setUsername] = useState(options.username);
  const [permissions, setPermissions] = useState(options.permissions);
  const [paymentPlanStatus, setPaymentPlanStatus] = useState(
    options.paymentPlanStatus
  );
  const [paymentPlanTrialEnd, setPaymentPlanTrialEnd] = useState(
    options.paymentPlanTrialEnd
  );
  const [paymentPlanCanceledAt, setPaymentPlanCanceledAt] = useState(
    options.paymentPlanCanceledAt
  );

  return (
    <SideBarContext.Provider
      value={{
        username,
        setUsername,
        permissions,
        setPermissions,
        paymentPlanStatus,
        setPaymentPlanStatus,
        paymentPlanTrialEnd,
        setPaymentPlanTrialEnd,
        paymentPlanCanceledAt,
        setPaymentPlanCanceledAt,
      }}
    >
      {children}
    </SideBarContext.Provider>
  );
}

// used to disabled the store menu in the SideBar, the store routes in AppRoutes and change the color of the trail end popup in the SideBar
export function getDaysLeft(paymentPlanTrialEnd) {
  return Math.floor(
    (new Date(paymentPlanTrialEnd) - new Date()) / (1000 * 60 * 60 * 24)
  );
}

export function hasTrailEnded(paymentPlanTrialEnd) {
  if (!paymentPlanTrialEnd) return false;

  return getDaysLeft(paymentPlanTrialEnd) <= 0;
}
